@@ -4,6 +4,15 @@ knitr::opts_chunk$set(
   comment = "#>",
   eval = nzchar(Sys.getenv("COMPILE_VIG"))
 )
+# Adding a check for CensusMapper server status. There are occasional cert and other issues affecting CensusMapper servers, and this causes failure of some automated testing - CRAN in particular. If this check passes, we move on and compile the rest of the vignette. If it fails, we compile without evaluating. 
+check <- tryCatch(get_census(dataset='CA16', regions=list(CMA="59933"),
+           vectors=c("v_CA16_408"),
+           level='CMA', use_cache = FALSE, geo_format = NA), error = function(e) {print("Invalid")})
+
+if(class(check)=="character") {
+  eval = FALSE
+}
+mb_token <- Sys.getenv("MB_TOKEN")
 
 ## ---- message = FALSE, warning = FALSE----------------------------------------
 library(cancensus)
@@ -34,7 +43,7 @@ ggplot(toronto) + geom_sf(aes(fill = median_hh_income), colour = "grey") +
   labs(title = "Median Household Income", subtitle = "Toronto Census Subdivisions, 2016 Census")
 
 ## ----message=FALSE, warning=FALSE, include=FALSE------------------------------
-# This chunk disables leaflet output in remaining chunks for PDF vignettes
+# This chunk disables leaflet and mapdeck output in remaining chunks for PDF vignettes
 if(Sys.getenv("COMPILE_VIG")!="TRUE") {
   knitr::opts_chunk$set(eval = FALSE)}
 
